#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 http-download
version:              0.2.1.0
visibility:           public
id:                   http-download-0.2.1.0-GkTyehztEurE2nmcNgjjVh
key:                  http-download-0.2.1.0-GkTyehztEurE2nmcNgjjVh
license:              BSD-3-Clause
copyright:            2018-2023 FP Complete
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/commercialhaskell/http-download#readme
synopsis:             Verified downloads with retries
description:
    Higher level HTTP download APIs include verification of content and retries

category:             Development
abi:                  804ad5ec935fcbc1c655d7da04733f1e
exposed:              True
exposed-modules:      Network.HTTP.Download Network.HTTP.Download.Verified
hidden-modules:       Paths_http_download
import-dirs:          /usr/lib/ghc-9.6.6/site-local/http-download-0.2.1.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/http-download-0.2.1.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/http-download-0.2.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-http-download
hs-libraries:         HShttp-download-0.2.1.0-GkTyehztEurE2nmcNgjjVh
depends:
    base-4.18.2.1 base64-bytestring-1.2.1.0-EmY0767ffFE8tBeH3slcY
    bytestring-0.11.5.3 conduit-1.3.6.1-8P16HBmakUKG1It6ArZYEY
    conduit-extra-1.3.8-LOPp6e09V66LxLJXrnknNu
    crypton-1.0.4-218iYZKZyEH9qzNK0rIxzf
    crypton-conduit-0.2.3-IHRDHSbRTuJIU1SHbf4a5Y directory-1.3.8.5
    exceptions-0.10.7 filepath-1.4.300.1
    http-client-0.7.19-A1qGvj2MlivKXlcAABR34l
    http-conduit-2.3.9.1-KjEJYPYZO4SBblo4w3yP8J
    http-types-0.12.4-CCQmPdMOAQMGVpO7SZrjGJ
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5
    path-0.9.6-BkxkylszPOt5vJvNCVsG0a
    path-io-1.8.2-9xel65tWo62Cf89Vgt2nX7
    retry-0.9.3.1-Em8OXhcO1BnFSqwIXyQqas
    rio-0.1.24.0-JhfLBiYR2lJIQwP2I6JdTi
    rio-prettyprint-0.1.8.0-FIjBJIuQJuVLDFsjI2nXFW

haddock-interfaces:
    /usr/share/doc/haskell-http-download/html/http-download.haddock

haddock-html:         /usr/share/doc/haskell-http-download/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

